### Glyphs Remote Script 

This is a script that has some examples how to control Glyphs from outside of the app. Unfortunately, the nice wrapper is not available, so one needs to use the methods provided by the PyObjC bridge.